import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { classnames } from "./classnames.js";
// Helpers
//////////////////////////////////////////////////////////////////////
const are = (arg) => arg ? `are-${arg}` : undefined;
const is = (arg) => arg ? `is-${arg}` : undefined;
// Components
//////////////////////////////////////////////////////////////////////
export const A = ({ bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, bulma), ...props, children: children }));
export const Article = ({ bulma, className, children, ...props }) => (_jsx("article", { className: classnames(className, bulma), ...props, children: children }));
/**
 * A breadcrumb component to improve navigation experience.
 *
 * @example
 *
 * ```tsx
 * <Breadcrumb isCentered aria-label="breadcrumbs">
 *   <BreadcrumbItem href="https://bulma.io/">Bulma</BreadcrumbItem>
 *   <BreadcrumbItem isActive>Trunx</BreadcrumbItem>
 * </Breadcrumb>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/breadcrumb/)
 */
export const Breadcrumb = ({ isCentered, isRight, bulma, className, children, ...props }) => (_jsx("nav", { className: classnames(className, "breadcrumb", {
        "is-centered": isCentered,
        "is-right": isRight,
    }, bulma), ...props, children: children }));
/** @see {@link Breadcrumb} */
export const BreadcrumbItem = ({ isActive, className, children, ...props }) => (_jsx("li", { className: classnames(className, { "is-active": isActive }), children: _jsx("a", { ...props, children: children }) }));
/**
 * The classic button, in different colors, sizes, and states.
 *
 * @example
 *
 * ```tsx
 * <Button color="primary" variant="light" isLoading>Login</Button>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/button/)
 */
export const Button = ({ isLoading, isFullwidth, isOutlined, color, isInverted, isRounded, size, variant, bulma, className, children, ...props }) => (_jsx("button", { className: classnames(className, "button", is(color), is(variant), is(size), {
        "is-fullwidth": isFullwidth,
        "is-loading": isLoading,
        "is-inverted": isInverted,
        "is-outlined": isOutlined,
        "is-rounded": isRounded,
    }, bulma), ...props, children: children }));
export const Buttons = ({ size, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "buttons", are(size), bulma), ...props, children: children }));
/**
 * Grid cell.
 *
 * @example
 *
 * ```tsx
 * <FixedGrid bulma="has-4-cols">
 *   <Cell>cell 1</Cell>
 *   <Cell bulma="is-col-start-3">cell 2</Cell>
 *   <Cell>cell 3</Cell>
 *   <Cell>cell 4</Cell>
 *   <Cell>cell 5</Cell>
 *   <Cell>cell 6</Cell>
 * </FixedGrid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/grid-cells/)
 *
 * Nope! Not that {@link https://en.wikipedia.org/wiki/Cell_(Dragon_Ball) | Cell} 😂.
 */
export const Cell = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "cell", bulma), ...props, children: children }));
/**
 * An all-around flexible and composable component.
 *
 * @example
 *
 * ```tsx
 * <Card>
 *   <CardHeader>
 *     <CardHeaderTitle>Title</CardHeaderTitle>
 *     <CardHeaderIcon>
 *       <Icon><i className="fas fa-angle-down" aria-hidden="true" /></Icon>
 *     </CardHeaderIcon>
 *   </CardHeader>
 *   <CardContent>
 *     Lorem ipsum...
 *   </CardContent>
 *   <CardFooter>
 *     <A bulma="card-footer-item">Save</A>
 *     <A bulma="card-footer-item">Delete</A>
 *   </CardFooter>
 * </Card>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/card/)
 */
export const Card = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "card", bulma), ...props, children: children }));
/** @see {@link Card} */
export const CardContent = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "card-content", bulma), ...props, children: children }));
/** @see {@link Card} */
export const CardFooter = ({ bulma, className, children, ...props }) => (_jsx("footer", { className: classnames(className, "card-footer", bulma), ...props, children: children }));
/** @see {@link Card} */
export const CardHeader = ({ bulma, className, children, ...props }) => (_jsx("footer", { className: classnames(className, "card-header", bulma), ...props, children: children }));
/** @see {@link Card} */
export const CardHeaderIcon = ({ bulma, className, children, ...props }) => (_jsx("button", { className: classnames(className, "card-header-icon", bulma), ...props, children: children }));
/** @see {@link Card} */
export const CardHeaderTitle = ({ bulma, className, children, ...props }) => (_jsx("p", { className: classnames(className, "card-header-title", bulma), ...props, children: children }));
/**
 * The 2-state checkbox in its native format
 *
 * @example
 *
 * ```tsx
 * <Checkbox disabled>Save my preferences</Checkbox>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/checkbox/)
 */
export const Checkbox = ({ children, ...props }) => (_jsxs("label", { className: "checkbox", children: [_jsx("input", { type: "checkbox", ...props }), children] }));
/** @see {@link Columns} */
export const Column = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "column", bulma), ...props, children: children }));
/**
 * The power of Flexbox in a simple interface.
 *
 * @see [bulma docs](https://bulma.io/documentation/columns/)
 */
export const Columns = ({ isDesktop, isGapless, isMobile, isMultiline, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "columns", {
        "is-gapless": isGapless,
        "is-desktop": isDesktop,
        "is-mobile": isMobile,
        "is-multiline": isMultiline,
    }, bulma), ...props, children: children }));
/**
 * A simple container to center your content horizontally.
 *
 * @example
 *
 * ```tsx
 * <Container isFluid>
 *   <Notification color="primary">
 *     This container is <strong>fluid</strong>
 *   </Notification>
 * </Container>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/container/)
 */
export const Container = ({ isWidescreen, isFluid, isMaxDesktop, isMaxWidescreen, isFullhd, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "container", {
        "is-widescreen": isWidescreen,
        "is-fullhd": isFullhd,
        "is-fluid": isFluid,
        // @ts-ignore Bulma generated types do not contain `is-max-desktop`.
        "is-max-desktop": isMaxDesktop,
        "is-max-widescreen": isMaxWidescreen,
    }, bulma), ...props, children: children }));
/**
 * A container for text.
 *
 * @example
 *
 * <Content size="small">
 *   <h1>Hello World</h1>
 *   <p>Lorem ipsum...</p>
 * </Content>
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/content/)
 */
export const Content = ({ size, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "content", is(size), bulma), ...props, children: children }));
export const Control = ({ hasIconsLeft, hasIconsRight, isExpanded, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "control", {
        "is-expanded": isExpanded,
        "has-icons-left": hasIconsLeft,
        "has-icons-right": hasIconsRight,
    }, bulma), ...props, children: children }));
/**
 * A versatile delete cross.
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/delete/)
 */
export const Delete = ({ size, className, children, ...props }) => (_jsx("button", { className: classnames(className, "delete", is(size)), ...props }));
export const Div = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, bulma), ...props, children: children }));
/**
 * Form field.
 *
 * @example
 *
 * ```tsx
 * <Field>
 *   <Label>Name</Label>
 *   <Control>
 *     <Input placeholder="e.g Alex Smith" />
 *   </Control>
 * </Field>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/general/#form-field)
 */
export const Field = ({ hasAddons, hasAddonsCentered, hasAddonsRight, isGrouped, isGroupedCentered, isGroupedMultiline, isGroupedRight, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "field", {
        "has-addons": hasAddons,
        "has-addons-centered": hasAddonsCentered,
        "has-addons-right": hasAddonsRight,
        "is-grouped": isGrouped,
        "is-grouped-centered": isGroupedCentered,
        "is-grouped-multiline": isGroupedMultiline,
        "is-grouped-right": isGroupedRight,
    }, bulma), ...props, children: children }));
/** @see {@link FieldHorizontal} */
export const FieldBody = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "field-body", bulma), ...props, children: children }));
/**
 * A horizontal form control.
 *
 * @example
 *
 * ```tsx
 * <FieldHorizontal>
 *   <FieldLabel isNormal>
 *     <Label>From</Label>
 *   </FieldLabel>
 *   <FieldBody>
 *     <Field>
 *       <Control>
 *         <Input type="text" placeholder="Name" />
 *       </Control>
 *     </Field>
 *     <Field>
 *       <Control>
 *         <Input type="email" placeholder="Email" />
 *       </Control>
 *     </Field>
 *   </FieldBody>
 * </FieldHorizontal>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/general/#horizontal-form)
 */
export const FieldHorizontal = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "field", "is-horizontal", bulma), ...props, children: children }));
/** @see {@link FieldHorizontal} */
export const FieldLabel = ({ isNormal, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "field-label", {
        "is-normal": isNormal,
    }, bulma), ...props, children: children }));
/**
 * A custom file upload input.
 *
 * @see [bulma docs](https://bulma.io/documentation/form/file/)
 */
export const FileUpload = ({ cta, hasName, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "file", bulma), ...props, children: _jsxs("label", { className: "file-label", children: [_jsx("input", { type: "file", ...props }), cta ? _jsx("span", { className: "file-cta", children: cta }) : null, hasName ? _jsx("span", { className: "file-name", children: hasName }) : null] }) }));
/**
 * A customizable 2D fixed grid.
 *
 * @example
 *
 * ```tsx
 * <FixedGrid hasAutoCount>
 *   <Cell>cell 1</Cell>
 *   <Cell>cell 2</Cell>
 * </FixedGrid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/fixed-grid/)
 */
export const FixedGrid = ({ hasAutoCount, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "fixed-grid", {
        "has-auto-count": hasAutoCount,
    }, bulma), ...props, children: _jsx("div", { className: "grid", children: children }) }));
/** A simple responsive footer.
 *
 * @example
 *
 * ```tsx
 * <Footer>
 *   <Content bulma="has-text-centered">
 *     <p>
 *       <strong>trunx</strong> by <a href="https://fibo.github.io">fibo</a>.
 *       The source code is licensed
 *       <a href="http://opensource.org/licenses/mit-license.php">MIT</a>.
 *     </p>
 *   </Content>
 * </Footer>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/footer/)
 */
export const Footer = ({ bulma, className, children, ...props }) => (_jsx("footer", { className: classnames(className, "footer", bulma), ...props, children: children }));
/**
 * A smart 2D grid with flexible columns.
 *
 * @example
 *
 * ```tsx
 * <Grid bulma={["is-col-min-4", "is-gap-2"]}>
 *   <Cell>cell 1</Cell>
 *   <Cell>cell 2</Cell>
 * </Grid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/smart-grid/)
 */
export const Grid = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "grid", bulma), ...props, children: children }));
export const Help = ({ color, bulma, className, children, ...props }) => (_jsx("p", { className: classnames(className, "help", is(color), bulma), ...props, children: children }));
/**
 * An imposing hero banner to showcase something.
 *
 * @example
 *
 * ```tsx
 * <Hero size="small">
 *   <HeroBody>
 *     <Title>Title</Title>
 *     <Subtitle>Subtitle</Subtitle>
 *   </HeroBody>
 * </Hero>
 * ```
 *
 * @example Half height hero
 *
 * ```tsx
 * <Hero color="success" isHalfheight>
 *   <HeroBody>
 *     <Title>Title</Title>
 *     <Subtitle>Subtitle</Subtitle>
 *   </HeroBody>
 * </Hero>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/hero/)
 */
export const Hero = ({ color, size, isHalfheight, isFullheight, isFullheightWithNavbar, bulma, className, children, ...props }) => (_jsx("section", { className: classnames(className, "hero", is(color), is(size), {
        "is-halfheight": isHalfheight,
        "is-fullheight": isFullheight,
        "is-fullheight-with-navbar": isFullheightWithNavbar,
    }, bulma), ...props, children: children }));
/** @see {@link Hero} */
export const HeroBody = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "hero-body", bulma), ...props, children: children }));
/** @see {@link Hero} */
export const HeroFoot = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "hero-foot", bulma), ...props, children: children }));
/** @see {@link Hero} */
export const HeroHead = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "hero-head", bulma), ...props, children: children }));
/**
 * A container for any type of icon.
 *
 * @example
 *
 * ```tsx
 * <Icon>
 *   <i className="fas fa-home"></i>
 * </Icon>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/icon/).
 */
export const Icon = ({ isLeft, isRight, size, bulma, className, children, ...props }) => (_jsx("span", { className: classnames(className, "icon", is(size), {
        "is-left": isLeft,
        "is-right": isRight,
    }, bulma), ...props, children: children }));
/**
 * Combine an icon with text.
 *
 * @example
 *
 * ```tsx
 * <IconText>
 *   <Icon bulma="has-text-primary">
 *     <i className="fas fa-home"></i>
 *   </Icon>
 *   <span>Home</span>
 * </IconText>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/icon/#icon-text)
 */
export const IconText = ({ bulma, className, children, ...props }) => (_jsx("span", { className: classnames(className, "icon-text", bulma), ...props, children: children }));
/**
 * A container for responsive images.
 *
 * @example Fixed square images
 *
 * ```tsx
 * <Image dimension="128x128">
 *   <img src="https://bulma.io/assets/images/placeholders/128x128.png" />
 * </Image>
 * ```
 *
 * @example Rounded images
 *
 * ```tsx
 * <Image dimension="128x128">
 *   <img className="is-rounded" src="https://bulma.io/assets/images/placeholders/256x256.png" />
 * </Image>
 * ```
 *
 * @example Arbitrary ratios with any element
 *
 * ```tsx
 * <Image ratio="16by9">
 *   <iframe
 *     className="has-ratio"
 *     width="640"
 *     height="360"
 *     src="https://www.youtube.com/embed/YE7VzlLtp-4"
 *     allowFullScreen
 *   />
 * </Image>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/image/)
 */
export const Image = ({ dimension, ratio, isSquare, bulma, className, children, ...props }) => (_jsx("figure", { className: classnames(className, "image", dimension ? `is-${dimension}` : undefined, ratio ? `is-${ratio}` : undefined, {
        "is-square": isSquare,
    }, bulma), ...props, children: children }));
export const Input = ({ bulma, className, color, size, ...props }) => (_jsx("input", { className: classnames(className, "input", is(color), is(size), bulma), ...props }));
/** Renders label tag with label class. */
export const Label = ({ bulma, className, children, ...props }) => (_jsx("label", { className: classnames(className, "label", bulma), ...props, children: children }));
/**
 * The famous media object prevalent in social media interfaces.
 *
 * @example
 *
 * ```tsx
 * <Media>
 *   <MediaLeft dimension="64x64">
 *     <img src="https://bulma.io/assets/images/placeholders/128x128.png" />
 *   </MediaLeft>
 *   <MediaContent>
 *     Content
 *   </MediaContent>
 *   <MediaRight>
 *     <Delete />
 *   </MediaRight>
 * </Media>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/media-object/)
 */
export const Media = ({ bulma, className, children, ...props }) => (_jsx("article", { className: classnames(className, "media", bulma), ...props, children: children }));
/** @see {@link Media} */
export const MediaContent = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "media-content", bulma), ...props, children: children }));
/** @see {@link Media} */
export const MediaLeft = ({ dimension, bulma, className, children, ...props }) => (_jsx("figure", { className: classnames(className, "media-left", bulma), ...props, children: _jsx("p", { className: classnames("image", dimension ? `is-${dimension}` : undefined), children: children }) }));
/** @see {@link Media} */
export const MediaRight = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "media-right", bulma), ...props, children: children }));
/**
 * A simple menu, for any type of vertical navigation.
 *
 * Renders aside tag with menu class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/menu/)
 */
export const Menu = ({ bulma, className, children, ...props }) => (_jsx("aside", { className: classnames(className, "menu", bulma), ...props, children: children }));
/** Renders p tag with menu-label class. */
export const MenuLabel = ({ bulma, className, children, ...props }) => (_jsx("p", { className: classnames(className, "menu-label", bulma), ...props, children: children }));
/** Renders ul tag with menu-list class. */
export const MenuList = ({ bulma, className, children, ...props }) => (_jsx("ul", { className: classnames(className, "menu-list", bulma), ...props, children: children }));
/**
 * Colored message blocks, to emphasize part of your page.
 *
 * Renders article tag with message class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/message/)
 */
export const Message = ({ header, bulma, className, children, ...props }) => (_jsxs("article", { className: classnames(className, "message", bulma), ...props, children: [header ? _jsx("div", { className: "message-header", children: header }) : null, _jsx("div", { className: "message-body", children: children })] }));
/**
 * A classic modal overlay, in which you can include any content you want.
 *
 * Renders div tag with modal class.
 *
 * ```tsx
 * <Modal noBackground>
 *   <ModalContent>
 *     Content
 *   </ModalContent>
 *   <ModalClose />
 * </Modal>
 * ```
 * @see [bulma docs](https://bulma.io/documentation/components/modal/)
 */
export const Modal = ({ noBackground, size, bulma, className, children, ...props }) => (_jsxs("div", { className: classnames(className, "modal", is(size), bulma), ...props, children: [noBackground ? null : _jsx("div", { className: "modal-background" }), children] }));
/**
 * A modal with a head, a body and a foot.
 *
 * Renders div tag with modal-card class.
 *
 * @example
 *
 * ```tsx
 * <ModalCard
 *   head="Modal title"
 *   foot={<Buttons><Button>Ok</Button></Buttons>}
 * >
 *   Content ...
 * </ModalCard>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/modal/#modal-card)
 */
export const ModalCard = ({ head, foot, className, children, ...props }) => (_jsxs("div", { className: classnames(className, "modal-card"), ...props, children: [_jsx("div", { className: "modal-card-head", children: head }), children, _jsxs("div", { className: "modal-card-foot", children: [" ", foot, " "] })] }));
/** Renders button tag with modal-close class. */
export const ModalClose = ({ size, className, ...props }) => (_jsx("button", { className: classnames(className, "modal-close", is(size)), ...props }));
/** Renders div tag with modal-content class. */
export const ModalContent = ({ bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "modal-content", bulma), ...props, children: children }));
export const Nav = ({ bulma, className, children, ...props }) => (_jsx("nav", { className: classnames(className, bulma), ...props, children: children }));
/**
 * A responsive horizontal navbar that can support images, links, buttons, and dropdowns.
 *
 * Renders nav tag with navbar class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/)
 */
export const Navbar = ({ color, role = "navigation", bulma, className, children, ...props }) => (_jsx("nav", { className: classnames(className, "navbar", is(color), bulma), role: role, ...props, children: children }));
/**
 * The NavbarBrand is the left side of the navbar.
 *
 * Renders div tag with navbar-brand class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-brand)
 */
export const NavbarBrand = ({ children }) => (_jsx("div", { className: "navbar-brand", children: children }));
/**
 * The NavbarBurger is a hamburger menu that only appears on touch devices.
 *
 * Renders a tag with navbar-burger class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-burger)
 */
export const NavbarBurger = ({ isActive, ...props }) => (_jsxs("a", { className: classnames("navbar-burger", { "is-active": isActive }), role: "button", "aria-expanded": isActive ? "true" : "false", ...props, children: [_jsx("span", { "aria-hidden": "true" }), _jsx("span", { "aria-hidden": "true" }), _jsx("span", { "aria-hidden": "true" }), _jsx("span", { "aria-hidden": "true" })] }));
/** Renders hr tag with navbar-divider class. */
export const NavbarDivider = () => _jsx("hr", { className: "navbar-divider" });
export const NavbarDropdown = ({ isBoxed, isRight, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "navbar-dropdown", {
        "is-boxed": isBoxed,
        "is-right": isRight,
    }, bulma), ...props, children: children }));
export const NavbarDropdownMenu = ({ hasDropdownUp, isActive, isHoverable, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "navbar-item", "has-dropdown", {
        "has-dropdown-up": hasDropdownUp,
        "is-active": isActive,
        "is-hoverable": isHoverable,
    }, bulma), ...props, children: children }));
export const NavbarEnd = ({ children }) => (_jsx("div", { className: "navbar-end", children: children }));
export const NavbarItem = ({ isSelected, bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, "navbar-item", {
        "is-selected": isSelected,
    }, bulma), ...props, children: children }));
export const NavbarLink = ({ isArrowless, bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, "navbar-link", {
        // @ts-ignore Bulma generated types do not contain `is-arrowless`.
        "is-arrowless": isArrowless,
    }, bulma), ...props, children: children }));
/**
 * The NavbarMenu is the counterpart of the NavbarBrand. As such, it must appear as a direct child of Navbar, as a sibling of NavbarBrand.
 *
 * @example
 *
 * ```tsx
 * <NavbarMenu>
 *   <NavbarStart>
 *     // Navbar items
 *   </NavbarStart>
 *   <NavbarEnd>
 *     // Navbar items
 *   </NavbarEnd>
 * </NavbarMenu>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-menu)
 */
export const NavbarMenu = ({ isActive, children, }) => (_jsx("div", { className: classnames("navbar-menu", { "is-active": isActive }), children: children }));
export const NavbarStart = ({ children }) => (_jsx("div", { className: "navbar-start", children: children }));
/**
 * Bold notification blocks, to alert your users of something.
 *
 * Renders div tag with notification class.
 *
 * @example
 *
 * ```tsx
 * <Notification color="info" variant="light">
 *   <Delete />
 *   Lorem ipsum...
 * </Notification>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/notification/)
 */
export const Notification = ({ color, variant, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "notification", is(color), is(variant), bulma), ...props, children: children }));
/**
 * Renders p tag.
 *
 * @example
 *
 * ```tsx
 * <P bulma="has-text-grey">Lorem ipsum...</P>
 * ```
 */
export const P = ({ bulma, className, children, ...props }) => (_jsx("p", { className: classnames(className, bulma), ...props, children: children }));
/**
 * A responsive, usable, and flexible pagination.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/pagination/)
 */
export const Pagination = ({ isCentered, isRight, size, role = "navigation", bulma, className, children, ...props }) => (_jsx("nav", { className: classnames(className, "pagination", is(size), {
        "is-centered": isCentered,
        "is-right": isRight,
    }, bulma), role: role, ...props, children: children }));
export const PaginationEllipsis = () => (_jsx("span", { className: "pagination-ellipsis", children: "\u2026" }));
export const PaginationLink = ({ isCurrent, bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, "pagination-link", { "is-current": isCurrent }, bulma), ...props, children: children }));
export const PaginationList = ({ bulma, className, children, ...props }) => (_jsx("ul", { className: classnames(className, "pagination-list", bulma), ...props, children: children }));
export const PaginationNext = ({ isDisabled, bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, "pagination-next", {
        "is-disabled": isDisabled,
    }, bulma), ...props, children: children }));
export const PaginationPrevious = ({ isDisabled, bulma, className, children, ...props }) => (_jsx("a", { className: classnames(className, "pagination-previous", {
        "is-disabled": isDisabled,
    }, bulma), ...props, children: children }));
/**
 * Native HTML progress bars.
 *
 * @example
 *
 * ```tsx
 * <Progress color="primary" size="small" value="42" max="100">42%</Progress>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/progress/)
 */
export const Progress = ({ size, bulma, className, children, ...props }) => (_jsx("progress", { className: classnames(className, "progress", is(size), bulma), ...props, children: children }));
export const Radio = ({ children, ...props }) => (_jsxs("label", { className: "radio", children: [_jsx("input", { type: "radio", ...props }), children] }));
export const Span = ({ bulma, className, children, ...props }) => (_jsx("span", { className: classnames(className, bulma), ...props, children: children }));
/**
 * A simple container to divide your page into sections.
 *
 * @example
 *
 * ```tsx
 * <Section size="medium">
 *   <Title tag="h2">Title</Title>
 * </Section>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/section/)
 */
export const Section = ({ size, bulma, className, children, ...props }) => (_jsx("section", { className: classnames(className, "section", is(size), bulma), ...props, children: children }));
/**
 * The browser built-in select dropdown, styled accordingly.
 *
 * @example
 *
 * ```tsx
 * <Select
 *   size="large"
 *   options={[
 *     { value: "A", label: "Apple" },
 *     { value: "B", label: "Banana" },
 *   ]}
 * />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/select/)
 */
export const Select = ({ options, isFullwidth, isLoading, isRounded, size, bulma, className, ...props }) => (_jsx("div", { className: classnames(className, "select", is(size), {
        "is-loading": isLoading,
        "is-fullwidth": isFullwidth,
        "is-rounded": isRounded,
    }, bulma), children: _jsx("select", { ...props, children: options.map((option) => (_jsx("option", { ...option }, option.value?.toString()))) }) }));
/**
 * @see {@link Title}
 */
export const Subtitle = ({ is, tag: Tag = "p", bulma, className, children, ...props }) => (_jsx(Tag, { className: classnames(className, "title", is ? `is-${is}` : undefined, bulma), ...props, children: children }));
/**
 * The inevitable HTML table, with special case cells.
 *
 * It <strong>always</strong> renders a <em>scrollable table</em>, that is a table inside a table container like this markup.
 *
 * ```html
 * <div class="table-container">
 *  <table class="table">
 *    <!-- Your table content -->
 *  </table>
 * </div>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/table/)
 */
export const Table = ({ bulma, className, children, ...props }) => (_jsx("div", { className: "table-container", children: _jsx("table", { className: classnames(className, "table", bulma), ...props, children: children }) }));
/**
 * Simple responsive horizontal navigation tabs, with different styles.
 *
 * @example
 *
 * ```tsx
 * <Tabs>
 *     <Tab isActive>Pictures</Tab>
 *     <Tab>Music</Tab>
 *     <Tab>Videos</Tab>
 * </Tabs>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/tabs/)
 */
export const Tabs = ({ isBoxed, isCentered, isFullwidth, isRight, isToggle, isToggleRounded, size, bulma, className, children, ...props }) => (_jsx("div", { className: classnames(className, "tabs", is(size), {
        "is-boxed": isBoxed,
        "is-centered": isCentered,
        "is-fullwidth": isFullwidth,
        "is-right": isRight,
        "is-toggle": isToggle,
        "is-toggle-rounded": isToggleRounded,
    }, bulma), ...props, children: _jsx("ul", { children: children }) }));
/** @see {@link Tabs} */
export const Tab = ({ isActive, className, children, ...props }) => (_jsx("li", { className: classnames(className, { "is-active": isActive }), children: _jsx("a", { ...props, children: children }) }));
/**
 * Small tag labels to insert anywhere.
 *
 * @example
 *
 * ```tsx
 * <Tag color="primary" variant="light">
 *   v1.0.0
 * </Tag>
 * ```
 *
 * @example Append a delete button.
 *
 * ```tsx
 * <Tag color="warning" size="medium">
 *   Hello
 *    <Delete size="small" />
 * </Tag>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/tag/).
 */
export const Tag = ({ color, variant, isHoverable, isRounded, size, bulma, className, children, ...props }) => (_jsx("span", { className: classnames(className, "tag", is(color), is(variant), is(size), {
        "is-hoverable": isHoverable,
        "is-rounded": isRounded,
    }, bulma), ...props, children: children }));
/**
 * List of tags.
 *
 * @example Size.
 *
 * ```tsx
 * <Tags size="large">
 *   <Tag>All</Tag>
 *   <Tag>Medium</Tag>
 *   <Tag>Size</Tag>
 * </Tags>
 * ```
 *
 * @example Attach tags together.
 *
 * ```tsx
 * <Tags hasAddons>
 *   <Tag>package</Tag>
 *   <Tag color="primary">trunx</Tag>
 * </Tags>
 * ```
 *
 * @example Attach a text tag with a delete tag together.
 *
 * ```tsx
 * <Tags hasAddons>
 *   <Tag color="danger">Alex Smith</Tag>
 *   <a class="tag is-delete" />
 * </Tags>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/tag/#list-of-tags)
 */
export const Tags = ({ hasAddons, size, className, children, ...props }) => (_jsx("div", { className: classnames(className, "tags", are(size), {
        "has-addons": hasAddons,
    }), ...props, children: children }));
/**
 * The multiline textarea and its variations.
 *
 * @example
 *
 * ```tsx
 * <Textarea size="small" color="info" />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/textarea/)
 */
export const Textarea = ({ color, size, isLoading, bulma, className, ...props }) => (_jsx("textarea", { className: classnames(className, "textarea", is(color), is(size), {
        "is-loading": isLoading,
    }, bulma), ...props }));
/**
 * Simple headings to add depth to your page.
 *
 * @example There are two types of heading: Title and Subtitle.
 *
 * ```ts
 * <Title tag="h1">Title</Title>
 * <Subtitle tag="h2">Subtitle</Subtitle>
 * ```
 *
 * @example Sizes
 *
 * ```ts
 * <Title is={1}>Title 1</Title>
 * <Title is={2}>Title 2</Title>
 * <Title is={3}>Title 3 (default)</Title>
 * <Title is={4}>Title 4</Title>
 * <Title is={5}>Title 5</Title>
 * <Title is={6}>Title 6</Title>
 * ```
 * @example Maintain the normal spacing between titles and subtitles.
 *
 * ```ts
 * <Title is={1} isSpaced>Title 1</Title>
 * <Subtitle is={3}>Subtitle 3</Subtitle>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/title/)
 */
export const Title = ({ is, isSpaced, tag: Tag = "p", bulma, className, children, ...props }) => (_jsx(Tag, { className: classnames(className, "title", is ? `is-${is}` : undefined, {
        "is-spaced": isSpaced,
    }, bulma), ...props, children: children }));
